@@ -11,7 +11,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 package Dpkg::Control::Fields;
 
@@ -20,7 +20,9 @@ use warnings;
 
 our $VERSION = '1.00';
 
+use Carp;
 use Exporter qw(import);
+
 use Dpkg::Control::FieldsCore;
 use Dpkg::Vendor qw(run_vendor_hook);
 
@@ -37,7 +39,7 @@ foreach my $op (run_vendor_hook('register-custom-fields')) {
     } elsif ($func eq 'insert_after') {
         &field_insert_after(@$op);
     } else {
-        internerr("vendor hook register-custom-fields sent bad data: @$op");
+        croak "vendor hook register-custom-fields sent bad data: @$op";
     }
 }
 
@@ -54,6 +56,12 @@ with associated meta-data explaining in which type of control information
 they are allowed. The vendor-neutral fieldnames and all functions are
 inherited from Dpkg::Control::FieldsCore.
 
+=head1 CHANGES
+
+=head2 Version 1.00
+
+Mark the module as public.
+
 =head1 AUTHOR
 
 Raphaël Hertzog <hertzog@debian.org>.
