@@ -11,7 +11,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 package Dpkg::Source::Archive;
 
@@ -25,6 +25,7 @@ use Dpkg::Gettext;
 use Dpkg::IPC;
 use Dpkg::ErrorHandling;
 
+use Carp;
 use File::Temp qw(tempdir);
 use File::Basename qw(basename);
 use File::Spec;
@@ -34,7 +35,7 @@ use parent qw(Dpkg::Compression::FileHandle);
 
 sub create {
     my ($self, %opts) = @_;
-    $opts{options} ||= [];
+    $opts{options} //= [];
     my %spawn_opts;
     # Possibly run tar from another directory
     if ($opts{chdir}) {
@@ -48,7 +49,7 @@ sub create {
     # Call tar creation process
     $spawn_opts{delete_env} = [ 'TAR_OPTIONS' ];
     $spawn_opts{exec} = [ 'tar', '--null', '-T', '-', '--numeric-owner',
-                            '--owner', '0', '--group', '0',
+                            '--owner', '0', '--group', '0', '--format=gnu',
                             @{$opts{options}}, '-cf', '-' ];
     *$self->{pid} = spawn(%spawn_opts);
     *$self->{cwd} = getcwd();
@@ -57,10 +58,10 @@ sub create {
 sub _add_entry {
     my ($self, $file) = @_;
     my $cwd = *$self->{cwd};
-    internerr('call create() first') unless *$self->{tar_input};
+    croak 'call create() first' unless *$self->{tar_input};
     $file = $2 if ($file =~ /^\Q$cwd\E\/(.+)$/); # Relative names
-    print({ *$self->{tar_input} } "$file\0") ||
-	    syserr(_g('write on tar input'));
+    print({ *$self->{tar_input} } "$file\0")
+        or syserr(_g('write on tar input'));
 }
 
 sub add_file {
@@ -69,7 +70,8 @@ sub add_file {
     if (*$self->{chdir}) {
         $testfile = File::Spec->catfile(*$self->{chdir}, $file);
     }
-    internerr("add_file() doesn't handle directories") if not -l $testfile and -d _;
+    croak 'add_file() does not handle directories'
+        if not -l $testfile and -d _;
     $self->_add_entry($file);
 }
 
@@ -79,7 +81,7 @@ sub add_directory {
     if (*$self->{chdir}) {
         $testfile = File::Spec->catdir(*$self->{chdir}, $file);
     }
-    internerr('add_directory() only handles directories')
+    croak 'add_directory() only handles directories'
         if -l $testfile or not -d _;
     $self->_add_entry($file);
 }
@@ -97,9 +99,9 @@ sub finish {
 
 sub extract {
     my ($self, $dest, %opts) = @_;
-    $opts{options} ||= [];
-    $opts{in_place} ||= 0;
-    $opts{no_fixperms} ||= 0;
+    $opts{options} //= [];
+    $opts{in_place} //= 0;
+    $opts{no_fixperms} //= 0;
     my %spawn_opts = (wait_child => 1);
 
     # Prepare destination
@@ -111,14 +113,14 @@ sub extract {
         my $template = basename($self->get_filename()) .  '.tmp-extract.XXXXX';
         unless (-e $dest) {
             # Kludge so that realpath works
-            mkdir($dest) || syserr(_g('cannot create directory %s'), $dest);
+            mkdir($dest) or syserr(_g('cannot create directory %s'), $dest);
         }
         $tmp = tempdir($template, DIR => Cwd::realpath("$dest/.."), CLEANUP => 1);
         $spawn_opts{chdir} = $tmp;
     }
 
     # Prepare stuff that handles the input of tar
-    $self->ensure_open('r');
+    $self->ensure_open('r', delete_sig => [ 'PIPE' ]);
     $spawn_opts{from_handle} = $self->get_filehandle();
 
     # Call tar extraction process
@@ -142,18 +144,18 @@ sub extract {
     return if $opts{in_place};
 
     # Rename extracted directory
-    opendir(my $dir_dh, $tmp) || syserr(_g('cannot opendir %s'), $tmp);
+    opendir(my $dir_dh, $tmp) or syserr(_g('cannot opendir %s'), $tmp);
     my @entries = grep { $_ ne '.' && $_ ne '..' } readdir($dir_dh);
     closedir($dir_dh);
     my $done = 0;
     erasedir($dest);
     if (scalar(@entries) == 1 && ! -l "$tmp/$entries[0]" && -d _) {
-	rename("$tmp/$entries[0]", $dest) ||
-		syserr(_g('Unable to rename %s to %s'),
-		       "$tmp/$entries[0]", $dest);
+	rename("$tmp/$entries[0]", $dest)
+	    or syserr(_g('unable to rename %s to %s'),
+	              "$tmp/$entries[0]", $dest);
     } else {
-	rename($tmp, $dest) ||
-		syserr(_g('Unable to rename %s to %s'), $tmp, $dest);
+	rename($tmp, $dest)
+	    or syserr(_g('unable to rename %s to %s'), $tmp, $dest);
     }
     erasedir($tmp);
 }
