@@ -14,7 +14,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 package Dpkg::Version;
 
@@ -26,6 +26,7 @@ our $VERSION = '1.01';
 use Dpkg::ErrorHandling;
 use Dpkg::Gettext;
 
+use Carp;
 use Exporter qw(import);
 our @EXPORT = qw(version_compare version_compare_relation
                  version_normalize_relation version_compare_string
@@ -263,7 +264,7 @@ sub version_compare_relation($$$) {
     } elsif ($op eq REL_LT) {
 	return $res < 0;
     } else {
-	internerr("unsupported relation for version_compare_relation(): '$op'");
+	croak "unsupported relation for version_compare_relation(): '$op'";
     }
 }
 
@@ -294,7 +295,7 @@ sub version_normalize_relation($) {
     } elsif ($op eq '<<' or $op eq 'lt') {
 	return REL_LT;
     } else {
-	internerr("bad relation '$op'");
+	croak "bad relation '$op'";
     }
 }
 
@@ -378,7 +379,9 @@ return ("1", ".", "024", "~beta", "1", "+svn", "234").
 =cut
 
 sub version_split_digits($) {
-    return split(/(?<=\d)(?=\D)|(?<=\D)(?=\d)/, $_[0]);
+    my $version = shift;
+
+    return split /(?<=\d)(?=\D)|(?<=\D)(?=\d)/, $version;
 }
 
 =item my ($ok, $msg) = version_check($version)
@@ -433,6 +436,10 @@ New argument: Accept an options argument in $v->as_string().
 
 New method: $v->is_native().
 
+=head2 Version 1.00
+
+Mark the module as public.
+
 =head1 AUTHOR
 
 Don Armstrong <don@donarmstrong.com>, Colin Watson
