@@ -252,6 +252,8 @@ symlink_to_dir() {
 		error "environment variable DPKG_MAINTSCRIPT_NAME is required"
 	[ -n "$PACKAGE" ] || error "cannot identify the package"
 	[ -n "$SYMLINK" ] || error "symlink parameter is missing"
+	[ "${SYMLINK#/}" = "$SYMLINK" ] && \
+		error "symlink pathname is not an absolute path"
 	[ -n "$SYMLINK_TARGET" ] || error "original symlink target is missing"
 	[ -n "$1" ] || error "maintainer script parameters are missing"
 
@@ -264,7 +266,7 @@ symlink_to_dir() {
 	preinst)
 		if [ "$1" = "install" -o "$1" = "upgrade" ] &&
 		   [ -n "$2" ] && [ -h "$SYMLINK" ] &&
-		   [ "$(readlink -f $SYMLINK)" = "$SYMLINK_TARGET" ] &&
+		   symlink_match "$SYMLINK" "$SYMLINK_TARGET" &&
 		   dpkg --compare-versions "$2" le-nl "$LASTVERSION"; then
 			mv -f "$SYMLINK" "${SYMLINK}.dpkg-backup"
 		fi
@@ -275,7 +277,7 @@ symlink_to_dir() {
 		# have been unpacked, then upgraded with an unpack and thus
 		# never been configured before.
 		if [ "$1" = "configure" ] && [ -h "${SYMLINK}.dpkg-backup" ] &&
-		   [ "$(readlink -f ${SYMLINK}.dpkg-backup)" = "$SYMLINK_TARGET" ]
+		   symlink_match "${SYMLINK}.dpkg-backup" "$SYMLINK_TARGET"
 		then
 			rm -f "${SYMLINK}.dpkg-backup"
 		fi
@@ -287,7 +289,7 @@ symlink_to_dir() {
 		if [ "$1" = "abort-install" -o "$1" = "abort-upgrade" ] &&
 		   [ -n "$2" ] &&
 		   [ ! -e "$SYMLINK" ] && [ -h "${SYMLINK}.dpkg-backup" ] &&
-		   [ "$(readlink -f ${SYMLINK}.dpkg-backup)" = "$SYMLINK_TARGET" ] &&
+		   symlink_match "${SYMLINK}.dpkg-backup" "$SYMLINK_TARGET" &&
 		   dpkg --compare-versions "$2" le-nl "$LASTVERSION"; then
 			echo "Restoring backup of $SYMLINK ..."
 			mv "${SYMLINK}.dpkg-backup" "$SYMLINK"
@@ -325,6 +327,8 @@ dir_to_symlink() {
 		error "environment variable DPKG_MAINTSCRIPT_NAME is required"
 	[ -n "$PACKAGE" ] || error "cannot identify the package"
 	[ -n "$PATHNAME" ] || error "directory parameter is missing"
+	[ "${PATHNAME#/}" = "$PATHNAME" ] && \
+		error "directory parameter is not an absolute path"
 	[ -n "$SYMLINK_TARGET" ] || error "new symlink target is missing"
 	[ -n "$1" ] || error "maintainer script parameters are missing"
 
@@ -364,7 +368,8 @@ dir_to_symlink() {
 		   [ \( ! -h "$PATHNAME" -a -d "$PATHNAME" -a \
 		        -f "$PATHNAME/.dpkg-staging-dir" \) -o \
 		     \( -h "$PATHNAME" -a \
-		        "$(readlink -f $PATHNAME)" = "$SYMLINK_TARGET" \) ] &&
+		        \( "$(readlink $PATHNAME)" = "$SYMLINK_TARGET" -o \
+		           "$(readlink -f $PATHNAME)" = "$SYMLINK_TARGET" \) \) ] &&
 		   dpkg --compare-versions "$2" le-nl "$LASTVERSION"; then
 			abort_dir_to_symlink "$PATHNAME"
 		fi
@@ -429,9 +434,15 @@ finish_dir_to_symlink()
 	# Move the contents of the staging directory to the symlink target,
 	# as those are all new files installed between this package being
 	# unpacked and configured.
+	local ABS_SYMLINK_TARGET
+	if [ "${SYMLINK_TARGET#/}" = "$SYMLINK_TARGET" ]; then
+		ABS_SYMLINK_TARGET="$(dirname "$PATHNAME")/$SYMLINK_TARGET"
+	else
+		ABS_SYMLINK_TARGET="$SYMLINK_TARGET"
+	fi
 	rm "$PATHNAME/.dpkg-staging-dir"
 	find "$PATHNAME" -mindepth 1 -print0 | \
-		xargs -0 -i% mv -f "%" "$SYMLINK_TARGET/"
+		xargs -0 -i% mv -f "%" "$ABS_SYMLINK_TARGET/"
 
 	# Remove the staging directory.
 	rmdir "$PATHNAME"
@@ -474,6 +485,15 @@ ensure_package_owns_file() {
 	return 0
 }
 
+symlink_match()
+{
+	local SYMLINK="$1"
+	local SYMLINK_TARGET="$2"
+
+	[ "$(readlink $SYMLINK)" = "$SYMLINK_TARGET" ] || \
+	[ "$(readlink -f $SYMLINK)" = "$SYMLINK_TARGET" ]
+}
+
 debug() {
 	if [ -n "$DPKG_DEBUG" ]; then
 		echo "DEBUG: $PROGNAME: $*" >&2
